@@ -1,21 +1,9 @@
-/*************************************************************************************
- *  Copyright (C) 2012 by Alejandro Fiestas Olivares <afiestas@kde.org>              *
- *  Copyright (C) 2014 by Daniel Vrátil <dvratil@redhat.com>                         *
- *                                                                                   *
- *  This library is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU Lesser General Public                       *
- *  License as published by the Free Software Foundation; either                     *
- *  version 2.1 of the License, or (at your option) any later version.               *
- *                                                                                   *
- *  This library is distributed in the hope that it will be useful,                  *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
- *  Lesser General Public License for more details.                                  *
- *                                                                                   *
- *  You should have received a copy of the GNU Lesser General Public                 *
- *  License along with this library; if not, write to the Free Software              *
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
- *************************************************************************************/
+/*
+ *  SPDX-FileCopyrightText: 2012 Alejandro Fiestas Olivares <afiestas@kde.org>
+ *  SPDX-FileCopyrightText: 2014 Daniel Vrátil <dvratil@redhat.com>
+ *
+ *  SPDX-License-Identifier: LGPL-2.1-or-later
+ */
 
 #include "config.h"
 #include "abstractbackend.h"
@@ -120,7 +108,7 @@ bool Config::canBeApplied(const ConfigPtr &config, ValidityFlags flags)
     OutputPtr currentOutput;
     const OutputList outputs = config->outputs();
     int enabledOutputsCount = 0;
-    Q_FOREACH (const OutputPtr &output, outputs) {
+    for (const OutputPtr &output : outputs) {
         if (!output->isEnabled()) {
             continue;
         }
@@ -292,7 +280,7 @@ OutputList Config::outputs() const
 OutputList Config::connectedOutputs() const
 {
     OutputList outputs;
-    Q_FOREACH (const OutputPtr &output, d->outputs) {
+    for (const OutputPtr &output : qAsConst(d->outputs)) {
         if (!output->isConnected()) {
             continue;
         }
@@ -378,13 +366,15 @@ void Config::apply(const ConfigPtr &other)
     d->screen->apply(other->screen());
 
     // Remove removed outputs
-    Q_FOREACH (const OutputPtr &output, d->outputs) {
-        if (!other->d->outputs.contains(output->id())) {
-            removeOutput(output->id());
+    for (auto it = d->outputs.begin(); it != d->outputs.end();) {
+        if (!other->d->outputs.contains((*it)->id())) {
+            it = d->removeOutput(it);
+        } else {
+            ++it;
         }
     }
 
-    Q_FOREACH (const OutputPtr &otherOutput, other->d->outputs) {
+    for (const OutputPtr &otherOutput : qAsConst(other->d->outputs)) {
         // Add new outputs
         if (!d->outputs.contains(otherOutput->id())) {
             addOutput(otherOutput->clone());
@@ -405,7 +395,7 @@ QDebug operator<<(QDebug dbg, const KScreen::ConfigPtr &config)
         const auto outputs = config->outputs();
         for (const auto &output : outputs) {
             if (output->isConnected()) {
-                dbg << endl << output;
+                dbg << Qt::endl << output;
             }
         }
         dbg << ")";
