@@ -1,20 +1,8 @@
-/*************************************************************************************
- *  Copyright 2016 Sebastian Kügler <sebas@kde.org>                                  *
- *                                                                                   *
- *  This library is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU Lesser General Public                       *
- *  License as published by the Free Software Foundation; either                     *
- *  version 2.1 of the License, or (at your option) any later version.               *
- *                                                                                   *
- *  This library is distributed in the hope that it will be useful,                  *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
- *  Lesser General Public License for more details.                                  *
- *                                                                                   *
- *  You should have received a copy of the GNU Lesser General Public                 *
- *  License along with this library; if not, write to the Free Software              *
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
- *************************************************************************************/
+/*
+ *  SPDX-FileCopyrightText: 2016 Sebastian Kügler <sebas@kde.org>
+ *
+ *  SPDX-License-Identifier: LGPL-2.1-or-later
+ */
 
 #include "dpmsclient.h"
 
@@ -92,7 +80,7 @@ void DpmsClient::connected()
             m_dpmsManager = m_registry->createDpmsManager(dpmsData.name, dpmsData.version);
         }
 
-        emit this->ready();
+        Q_EMIT this->ready();
     });
     m_registry->setup();
 
@@ -137,7 +125,7 @@ void DpmsClient::modeChanged()
 {
     m_modeChanges = m_modeChanges - 1;
     if (m_modeChanges <= 0) {
-        emit finished();
+        Q_EMIT finished();
         m_modeChanges = 0;
     }
 }
@@ -145,11 +133,11 @@ void DpmsClient::modeChanged()
 void DpmsClient::on()
 {
     changeMode(Dpms::Mode::On);
-    // emit finished();
+    // Q_EMIT finished();
 }
 
 void KScreen::DpmsClient::off()
 {
     changeMode(Dpms::Mode::Off);
-    // emit finished();
+    // Q_EMIT finished();
 }
