@@ -1,19 +1,7 @@
 /*
- * Copyright (C) 2014  Daniel Vratil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2014 Daniel Vratil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
  */
 
@@ -138,7 +126,8 @@ void SetConfigOperationPrivate::normalizeOutputPositions()
     }
     int offsetX = INT_MAX;
     int offsetY = INT_MAX;
-    Q_FOREACH (const KScreen::OutputPtr &output, config->outputs()) {
+    const auto outputs = config->outputs();
+    for (const KScreen::OutputPtr &output : outputs) {
         if (!output->isPositionable()) {
             continue;
         }
@@ -150,7 +139,7 @@ void SetConfigOperationPrivate::normalizeOutputPositions()
         return;
     }
     qCDebug(KSCREEN) << "Correcting output positions by:" << QPoint(offsetX, offsetY);
-    Q_FOREACH (const KScreen::OutputPtr &output, config->outputs()) {
+    for (const KScreen::OutputPtr &output : outputs) {
         if (!output->isConnected() || !output->isEnabled()) {
             continue;
         }
